==> djmessenger-0.0.3.dev20160828070234.tar.gz: djmessenger-0.0.3.dev20160828070234/setup.py <==
# -*- coding: utf-8 -*-
# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path


version = __import__('djmessenger').get_version()


here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='djmessenger',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=version,

    description='A simple framework to create powerful Facebook Messenger BOT',
    long_description='A simple framework to create powerful Facebook Messenger BOT',

    # The project's main homepage.
    url='https://github.com/ifanchu/djmessenger',

    # Author details
    author='Evan Chu',
    author_email='ifanchu@ifanchu.com',

    # Choose your license
    license='GNU GENERAL PUBLIC LICENSE Version 2',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.4'
    ],

    # What does your project relate to?
    keywords='facebook messenger bot',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['django', 'djangorestframework', 'requests'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #     'sample': ['package_data.dat'],
    # },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
)
# import os
# from setuptools import setup, find_packages
#
# README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()
#
# # Allow setup.py to be run from any path
# os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
#
# setup(
#     name='djmessenger',
#     version='0.0.1',
#     packages=find_packages(),
#     include_package_data=True,
#     license='BSD License',
#     description='A simple framework to create powerful Facebook Messenger BOT',
#     long_description=README,
#     url='https://github.com/ifanchu/djmessenger',
#     author='Evan Chu',
#     author_email='ifanchu@ifanchu.com',
#     classifiers=[
#         'Environment :: Web Environment',
#         'Framework :: Django',
#         'Intended Audience :: Developers',
#         'License :: OSI Approved :: GNU GENERAL PUBLIC LICENSE Version 2',
#         'Operating System :: OS Independent',
#         'Programming Language :: Python',
#         'Programming Language :: Python :: 3.4',
#         'Topic :: Internet :: WWW/HTTP',
#         'Topic :: Internet :: WWW/HTTP :: Dynamic Content'
#     ]
# )

==> djmessenger-1.0.4.tar.gz: djmessenger-1.0.4/setup.py <==
# -*- coding: utf-8 -*-
# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path


version = __import__('djmessenger').get_version()


here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='djmessenger',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=version,

    description='A simple framework to create powerful Facebook Messenger BOT',
    long_description='A simple framework to create powerful Facebook Messenger BOT',

    # The project's main homepage.
    url='https://github.com/ifanchu/djmessenger',

    # Author details
    author='Evan Chu',
    author_email='ifanchu@ifanchu.com',

    # Choose your license
    license='GNU GENERAL PUBLIC LICENSE Version 2',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.4'
    ],

    # What does your project relate to?
    keywords='facebook messenger bot',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['testapp', '*.testapp', 'testapp.*']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        'django>=1.9.8',
        'djangorestframework>=3.4.5',
        'requests>=2.11.1',
        'xmltodict>=0.10.2'
    ],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #     'sample': ['package_data.dat'],
    # },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
)
# import os
# from setuptools import setup, find_packages
#
# README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()
#
# # Allow setup.py to be run from any path
# os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
#
# setup(
#     name='djmessenger',
#     version='0.0.1',
#     packages=find_packages(),
#     include_package_data=True,
#     license='BSD License',
#     description='A simple framework to create powerful Facebook Messenger BOT',
#     long_description=README,
#     url='https://github.com/ifanchu/djmessenger',
#     author='Evan Chu',
#     author_email='ifanchu@ifanchu.com',
#     classifiers=[
#         'Environment :: Web Environment',
#         'Framework :: Django',
#         'Intended Audience :: Developers',
#         'License :: OSI Approved :: GNU GENERAL PUBLIC LICENSE Version 2',
#         'Operating System :: OS Independent',
#         'Programming Language :: Python',
#         'Programming Language :: Python :: 3.4',
#         'Topic :: Internet :: WWW/HTTP',
#         'Topic :: Internet :: WWW/HTTP :: Dynamic Content'
#     ]
# )
